==> genshitjokes-2023.5.24.tar.gz: genshitjokes-2023.5.24/genshitjokes/米孝子/米孝子.md <==
# 米孝子

## 一.爆金币   Kr

### 1.648的礼物

![](https://github.com/DreamingCats/GenshitJokes/raw/main/genshitjokes/米孝子/爆金币/648的礼物.jpg)

### 2.生日礼物   Birthday Gift

![](https://github.com/DreamingCats/GenshitJokes/raw/main/genshitjokes/米孝子/爆金币/生日礼物.jpg)

### 3.自愿充值   Voluntay Charge

![](https://github.com/DreamingCats/GenshitJokes/raw/main/genshitjokes/米孝子/爆金币/自愿充值.jpg)

### 4.七千生活费 -¥7000

![](https://github.com/DreamingCats/GenshitJokes/raw/main/genshitjokes/米孝子/爆金币/七千生活费.jpg)

<a href="https://www.zhihu.com/question/427305451/answer/1580649667" target="_blank">问题地址</a>

### 5.-6220

![](https://github.com/DreamingCats/GenshitJokes/raw/main/genshitjokes/米孝子/爆金币/-6220.jpg)

### 6.贷款冲原神   Loan

![](https://github.com/DreamingCats/GenshitJokes/raw/main/genshitjokes/米孝子/爆金币/贷款冲原神.jpg)

### 7.拆迁款冲原神   Demolition Money

![](https://github.com/DreamingCats/GenshitJokes/raw/main/genshitjokes/米孝子/爆金币/拆迁款冲原神.jpg)

### 8.稿费   Contribution Fee

![](https://github.com/DreamingCats/GenshitJokes/raw/main/genshitjokes/米孝子/爆金币/稿费.jpg)

## 二.谁是父母   Whosyourdaddy

### 1.原神生的   Mihoyo's Son

![](https://github.com/DreamingCats/GenshitJokes/raw/main/genshitjokes/米孝子/谁是父母/原神生的.jpg)

### 2.衣食父母   Mihoyo Is Feeding You

![](https://github.com/DreamingCats/GenshitJokes/raw/main/genshitjokes/米孝子/谁是父母/衣食父母.jpg)

### 3.不配   Unworthy

![](https://github.com/DreamingCats/GenshitJokes/raw/main/genshitjokes/米孝子/谁是父母/不配.jpg)

## 三.

### 1.日本网友   Overseas

![](https://github.com/DreamingCats/GenshitJokes/raw/main/genshitjokes/米孝子/日本网友.jpg)

### 2.懂得感恩   Thanksgiving

![](https://github.com/DreamingCats/GenshitJokes/raw/main/genshitjokes/米孝子/懂得感恩.jpg)

### 3.没有孝子   No Tiaogou

![](https://github.com/DreamingCats/GenshitJokes/raw/main/genshitjokes/米孝子/没有孝子.jpg)

### 4.老老实实跪着玩   Go Down On Mihoyo's Knees

![](https://github.com/DreamingCats/GenshitJokes/raw/main/genshitjokes/米孝子/老老实实跪着玩.jpg)

### 5.团结   Stick Together

![](https://github.com/DreamingCats/GenshitJokes/raw/main/genshitjokes/米孝子/团结.jpg)

### 6.我们联合   We Unite

![](https://github.com/DreamingCats/GenshitJokes/raw/main/genshitjokes/米孝子/我们联合.jpg)

### 7.原批挺好的   Genshit Seems Good

![](https://github.com/DreamingCats/GenshitJokes/raw/main/genshitjokes/米孝子/原批挺好的.jpg)

### 8.一样   The Same

一样丁真，鉴定为米孝子

![](https://github.com/DreamingCats/GenshitJokes/raw/main/genshitjokes/米孝子/一样.jpg)

### 9.态度   Attitude

![](https://github.com/DreamingCats/GenshitJokes/raw/main/genshitjokes/米孝子/态度问题.jpg)

![](https://github.com/DreamingCats/GenshitJokes/raw/main/genshitjokes/米孝子/什么态度.jpg)

### 10.原神不无聊   Not Boring

![](https://github.com/DreamingCats/GenshitJokes/raw/main/genshitjokes/米孝子/原神不无聊.jpg)

### 11.第二个世界   Another World

![](https://github.com/DreamingCats/GenshitJokes/raw/main/genshitjokes/米孝子/第二个世界.jpg)

### 12.利益受损   Profit Loss

![](https://github.com/DreamingCats/GenshitJokes/raw/main/genshitjokes/米孝子/利益受损.jpg)

### 13.买号等于偷钱   Buy Account==Steal Money

![](https://github.com/DreamingCats/GenshitJokes/raw/main/genshitjokes/米孝子/买号等于偷钱.jpg)

### 14.敬畏心   Revere

![](https://github.com/DreamingCats/GenshitJokes/raw/main/genshitjokes/米孝子/敬畏心.jpg)

==> genshitjokes-2023.5.26.tar.gz: genshitjokes-2023.5.26/genshitjokes/米孝子/米孝子.md <==
# 米孝子

## 一.爆金币   Kr

### 1.648的礼物

![](https://github.com/DreamingCats/GenshitJokes/raw/main/genshitjokes/米孝子/爆金币/648的礼物.jpg)

### 2.生日礼物   Birthday Gift

![](https://github.com/DreamingCats/GenshitJokes/raw/main/genshitjokes/米孝子/爆金币/生日礼物.jpg)

### 3.自愿充值   Voluntay Charge

![](https://github.com/DreamingCats/GenshitJokes/raw/main/genshitjokes/米孝子/爆金币/自愿充值.jpg)

### 4.七千生活费 -¥7000

![](https://github.com/DreamingCats/GenshitJokes/raw/main/genshitjokes/米孝子/爆金币/七千生活费.jpg)

<a href="https://www.zhihu.com/question/427305451/answer/1580649667" target="_blank">问题地址</a>

### 5.-6220

![](https://github.com/DreamingCats/GenshitJokes/raw/main/genshitjokes/米孝子/爆金币/-6220.jpg)

### 6.贷款冲原神   Loan

![](https://github.com/DreamingCats/GenshitJokes/raw/main/genshitjokes/米孝子/爆金币/贷款冲原神.jpg)

### 7.拆迁款冲原神   Demolition Money

![](https://github.com/DreamingCats/GenshitJokes/raw/main/genshitjokes/米孝子/爆金币/拆迁款冲原神.jpg)

### 8.稿费   Contribution Fee

![](https://github.com/DreamingCats/GenshitJokes/raw/main/genshitjokes/米孝子/爆金币/稿费.jpg)

## 二.谁是父母   Whosyourdaddy

### 1.原神生的   Mihoyo's Son

![](https://github.com/DreamingCats/GenshitJokes/raw/main/genshitjokes/米孝子/谁是父母/原神生的.jpg)

### 2.衣食父母   Mihoyo Is Feeding You

![](https://github.com/DreamingCats/GenshitJokes/raw/main/genshitjokes/米孝子/谁是父母/衣食父母.jpg)

### 3.不配   Unworthy

![](https://github.com/DreamingCats/GenshitJokes/raw/main/genshitjokes/米孝子/谁是父母/不配.jpg)

## 三.利益   Profit

### 1.利益受损   Profit Loss

![](https://github.com/DreamingCats/GenshitJokes/raw/main/genshitjokes/米孝子/利益/利益受损.jpg)

### 2.游戏公司的利益   Profit of Mihoyo

![](https://github.com/DreamingCats/GenshitJokes/raw/main/genshitjokes/米孝子/利益/游戏公司的利益.jpg)

### 3.买号等于偷钱   Buy Account==Steal Money

![](https://github.com/DreamingCats/GenshitJokes/raw/main/genshitjokes/米孝子/买号等于偷钱.jpg)

## 四.态度   Attitude

### 1.态度问题

![](https://github.com/DreamingCats/GenshitJokes/raw/main/genshitjokes/米孝子/态度/态度问题.jpg)

### 2.什么态度

![](https://github.com/DreamingCats/GenshitJokes/raw/main/genshitjokes/米孝子/态度/什么态度.jpg)

## 五.

### 1.日本网友   Overseas

![](https://github.com/DreamingCats/GenshitJokes/raw/main/genshitjokes/米孝子/日本网友.jpg)

### 2.懂得感恩   Thanksgiving

![](https://github.com/DreamingCats/GenshitJokes/raw/main/genshitjokes/米孝子/懂得感恩.jpg)

### 3.没有孝子   No Tiaogou

![](https://github.com/DreamingCats/GenshitJokes/raw/main/genshitjokes/米孝子/没有孝子.jpg)

### 4.老老实实跪着玩   Go Down On Mihoyo's Knees

![](https://github.com/DreamingCats/GenshitJokes/raw/main/genshitjokes/米孝子/老老实实跪着玩.jpg)

### 5.团结   Stick Together

![](https://github.com/DreamingCats/GenshitJokes/raw/main/genshitjokes/米孝子/团结.jpg)

### 6.我们联合   We Unite

![](https://github.com/DreamingCats/GenshitJokes/raw/main/genshitjokes/米孝子/我们联合.jpg)

### 7.原批挺好的   Genshit Seems Good

![](https://github.com/DreamingCats/GenshitJokes/raw/main/genshitjokes/米孝子/原批挺好的.jpg)

### 8.一样   The Same

一样丁真，鉴定为米孝子

![](https://github.com/DreamingCats/GenshitJokes/raw/main/genshitjokes/米孝子/一样.jpg)

### 9.原神不无聊   Not Boring

![](https://github.com/DreamingCats/GenshitJokes/raw/main/genshitjokes/米孝子/原神不无聊.jpg)

### 10.第二个世界   Another World

![](https://github.com/DreamingCats/GenshitJokes/raw/main/genshitjokes/米孝子/第二个世界.jpg)

### 11.敬畏心   Revere

![](https://github.com/DreamingCats/GenshitJokes/raw/main/genshitjokes/米孝子/敬畏心.jpg)
